Author: pgil
Date: Thu Mar 22 08:54:00 2018
New Revision: 1827470
URL:
http://svn.apache.org/viewvc?rev=1827470&view=revLog:
Fixed: Convert README.md to README.adoc.
(OFBIZ-10272)
Complete Jacques Fix, replacing all README.md occurence with README.adoc.
Modified:
ofbiz/ofbiz-framework/trunk/framework/base/groovyScript/test/FileUtilTests.groovy
Modified: ofbiz/ofbiz-framework/trunk/framework/base/groovyScript/test/FileUtilTests.groovy
URL:
http://svn.apache.org/viewvc/ofbiz/ofbiz-framework/trunk/framework/base/groovyScript/test/FileUtilTests.groovy?rev=1827470&r1=1827469&r2=1827470&view=diff==============================================================================
--- ofbiz/ofbiz-framework/trunk/framework/base/groovyScript/test/FileUtilTests.groovy (original)
+++ ofbiz/ofbiz-framework/trunk/framework/base/groovyScript/test/FileUtilTests.groovy Thu Mar 22 08:54:00 2018
@@ -26,15 +26,15 @@ import org.apache.ofbiz.testtools.Groovy
class FileUtilTests extends GroovyScriptTestCase {
/**
* Test FileUtil zipFileStream and unzipFileToFolder methods, using README.md
*/
void testZipReadme() {
String zipFilePath = UtilProperties.getPropertyValue("general", "http.upload.tmprepository", "runtime/tmp")
- String zipName = 'README.md.zip'
+ String zipName = 'README.adoc.zip'
String fileName = 'README.adoc'
File originalReadme = new File(fileName)
//validate zipStream from README.md is not null
def zipStream = FileUtil.zipFileStream(originalReadme.newInputStream(), fileName)
assert zipStream
@@ -52,7 +52,7 @@ class FileUtilTests extends GroovyScript
out.close()
zipStream.close()
//ensure no README.md exist in tmp folder
File readme = new File(zipFilePath, fileName)
if (readme.exists()) readme.delete()
@@ -26,15 +26,15 @@ import org.apache.ofbiz.testtools.Groovy
class FileUtilTests extends GroovyScriptTestCase {
/**
- * Test FileUtil zipFileStream and unzipFileToFolder methods, using README.md
+ * Test FileUtil zipFileStream and unzipFileToFolder methods, using README.adoc
*/
void testZipReadme() {
@@ -26,15 +26,15 @@ import org.apache.ofbiz.testtools.Groovy
String fileName = 'README.adoc'
File originalReadme = new File(fileName)
- //validate zipStream from README.md is not null
+ //validate zipStream from README.adoc is not null
def zipStream = FileUtil.zipFileStream(originalReadme.newInputStream(), fileName)
assert zipStream
@@ -52,7 +52,7 @@ class FileUtilTests extends GroovyScript
out.close()
zipStream.close()
- //ensure no README.md exist in tmp folder
+ //ensure no README.adoc exist in tmp folder
File readme = new File(zipFilePath, fileName)
if (readme.exists()) readme.delete()